summaryrefslogtreecommitdiffstats
path: root/chrome
diff options
context:
space:
mode:
Diffstat (limited to 'chrome')
-rw-r--r--chrome/test/functional/PYAUTO_TESTS3
-rwxr-xr-xchrome/test/pyautolib/chromeos/suid_actions.py14
2 files changed, 11 insertions, 6 deletions
diff --git a/chrome/test/functional/PYAUTO_TESTS b/chrome/test/functional/PYAUTO_TESTS
index 33f60b8..6ee74a6 100644
--- a/chrome/test/functional/PYAUTO_TESTS
+++ b/chrome/test/functional/PYAUTO_TESTS
@@ -746,8 +746,7 @@
'chromeos': [
'chromeos_ephemeral',
'chromeos_device_policy',
- # crosbug.com/32066
- # 'chromeos_onc',
+ 'chromeos_onc',
'policy',
'policy_prefs_ui',
# crbug.com/115427
diff --git a/chrome/test/pyautolib/chromeos/suid_actions.py b/chrome/test/pyautolib/chromeos/suid_actions.py
index d7dfe5f..9fe6679 100755
--- a/chrome/test/pyautolib/chromeos/suid_actions.py
+++ b/chrome/test/pyautolib/chromeos/suid_actions.py
@@ -48,14 +48,20 @@ class SuidAction(object):
## Actions ##
def CleanFlimflamDirs(self):
"""Clean the contents of all flimflam profiles.
TODO(stanleyw): crosbug.com/29421 This method restarts flimflam. It should
- wait until flimflam is fully initialized and accessible via DBus. Otherwise,
- there is a race conditions and subsequent accesses to flimflam may fail.
+ wait until flimflam/shill is fully initialized and accessible via DBus.
+ Otherwise, there is a race conditions and subsequent accesses to
+ flimflam/shill may fail.
"""
flimflam_dirs = ['/home/chronos/user/flimflam',
- '/var/cache/flimflam']
+ '/home/chronos/user/shill',
+ '/var/cache/flimflam',
+ '/var/cache/shill']
+
+ # The stop/start flimflam command should stop/start shill respectivly if
+ # enabled.
os.system('stop flimflam')
try:
for flimflam_dir in flimflam_dirs:
@@ -48,14 +48,20 @@ class SuidAction(object):
## Actions ##
def CleanFlimflamDirs(self):
- """Clean the contents of all flimflam profiles.
+ """Clean the contents of all connection manager (shill/flimflam) profiles.
TODO(stanleyw): crosbug.com/29421 This method restarts flimflam. It should